@@ -6,6 +6,10 @@ class DeviceVersionNotSupportedError(PyMobileDevice3Exception):
     pass
 
 
+class IncorrectModeError(PyMobileDevice3Exception):
+    pass
+
+
 class DeviceVersionFormatError(PyMobileDevice3Exception):
     pass
 
@@ -63,7 +67,9 @@ class ArgumentError(PyMobileDevice3Exception):
 
 
 class AfcException(PyMobileDevice3Exception):
-    pass
+    def __init__(self, message, status):
+        super(AfcException, self).__init__(message)
+        self.status = status
 
 
 class AfcFileNotFoundError(AfcException):
