@@ -12,7 +12,7 @@ from pymobiledevice3.ca import ca_do_everything
 from pymobiledevice3.exceptions import NoDeviceConnectedError, FatalPairingError, CannotStopSessionError, \
     NotTrustedError, \
     PairingError, NotPairedError, StartServiceError, DeviceNonConnectedError, PyMobileDevice3Exception, \
-    PasswordRequiredError, ConnectionFailedError
+    PasswordRequiredError, ConnectionFailedError, IncorrectModeError
 from pymobiledevice3.service_connection import ServiceConnection
 
 # we store pairing records and ssl keys in ~/.pymobiledevice3
@@ -84,7 +84,8 @@ class LockdownClient(object):
         self.paired = False
         self.label = client_name
 
-        assert self.query_type() == 'com.apple.mobile.lockdown'
+        if self.query_type() != 'com.apple.mobile.lockdown':
+            raise IncorrectModeError()
 
         self.all_values = self.get_value()
         self.udid = self.all_values.get('UniqueDeviceID')
@@ -111,6 +112,10 @@ class LockdownClient(object):
         res = self.service.recv_plist()
         return res.get('Type')
 
+    @property
+    def ecid(self):
+        return self.all_values['UniqueChipID']
+
     def generate_host_id(self):
         hostname = platform.node()
         hostid = uuid.uuid3(uuid.NAMESPACE_DNS, hostname)
@@ -225,6 +230,11 @@ class LockdownClient(object):
             self.service.close()
             raise PairingError()
 
+    def unpair(self):
+        req = {'Label': self.label, 'Request': 'Unpair', 'PairRecord': self.pair_record}
+        self.service.send_plist(req)
+        return self.service.recv_plist()
+
     def get_value(self, domain=None, key=None):
         if isinstance(key, str) and hasattr(self, 'record') and hasattr(self.pair_record, key):
             return self.pair_record[key]
