@@ -2,7 +2,7 @@ import logging
 
 from pymobiledevice3.lockdown import LockdownClient
 
-SRCFILES = """Baseband
+SRCFILES = '''Baseband
 CrashReporter
 MobileAsset
 VARFS
@@ -20,11 +20,7 @@ NANDDebugInfo
 SystemConfiguration
 Ubiquity
 tmp
-WirelessAutomation"""
-
-
-class DeviceVersionNotSupported(Exception):
-    pass
+WirelessAutomation'''
 
 
 class FileRelayService(object):
@@ -37,17 +33,19 @@ class FileRelayService(object):
         self.packet_num = 0
 
     def stop_session(self):
-        self.logger.info("Disconecting...")
+        self.logger.info('Disconecting...')
         self.service.close()
 
-    def request_sources(self, sources=["UserDatabases"]):
-        self.service.send_plist({"Sources": sources})
+    def request_sources(self, sources=None):
+        if sources is None:
+            sources = ['UserDatabases']
+        self.service.send_plist({'Sources': sources})
         while 1:
             res = self.service.recv_plist()
             if res:
-                s = res.get("Status")
-                if s == "Acknowledged":
-                    z = ""
+                s = res.get('Status')
+                if s == 'Acknowledged':
+                    z = ''
                     while True:
                         x = self.service.recv()
                         if not x:
@@ -55,6 +53,6 @@ class FileRelayService(object):
                         z += x
                     return z
                 else:
-                    print(res.get("Error"))
+                    print(res.get('Error'))
                     break
         return None
