@@ -1,6 +1,5 @@
 import logging
 
-from pymobiledevice3.exceptions import PyMobileDevice3Exception
 from pymobiledevice3.lockdown import LockdownClient
 
 
@@ -17,11 +16,6 @@ class NotificationProxyService(object):
         self.service.send_plist({'Command': 'PostNotification',
                                  'Name': name})
 
-        self.service.send_plist({'Command': 'Shutdown'})
-        res = self.service.recv_plist()
-        if res.get('Command', None) != 'ProxyDeath':
-            raise PyMobileDevice3Exception(f'invalid response: {res}')
-
     def notify_register_dispatch(self, name):
         """ Tells the device to send a notification on the specified event. """
         self.logger.info('Observing %s', name)
